@@ -29,11 +29,11 @@
 #include <string.h>
 #include <fcntl.h>
 #include <netinet/in.h>
-#include <linux/if_ether.h>
-#include <linux/ip.h>
-#include <linux/tcp.h>
-#include <linux/udp.h>
-#include <linux/icmp.h>
+#include <netinet/if_ether.h>
+#include <netinet/ip.h>
+#include <netinet/tcp.h>
+#include <netinet/udp.h>
+#include <netinet/ip_icmp.h>
 #include <net/if.h>
 #include <bits/time.h>
 #include <sys/socket.h>
@@ -47,7 +47,7 @@
 #include <pcap.h>
 #include "list.h"
 
-static char version[] = "0.3";
+static char version[] = "0.3.1";
 
 #define SEQ_TIMEOUT 25 /* default knock timeout in seconds */
 #define CMD_TIMEOUT 10 /* default timeout in seconds between start and stop commands */
@@ -179,8 +179,7 @@ int main(int argc, char **argv)
 			dprint("ppp interface detected (linux \"cooked\" encapsulation)\n");
 			break;
 		default: 
-			fprintf(stderr, "error: unsupported link-layer type: %s\n",
-					pcap_datalink_val_to_name(lltype));
+			fprintf(stderr, "error: unsupported link-layer type: %d\n", lltype);
 			cleanup(1);
 			break;
 	}
